summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorRay <[email protected]>2018-06-01 00:53:40 +0200
committerRay <[email protected]>2018-06-01 00:53:40 +0200
commit2536bea379387e525e3107ee07355292ee87a566 (patch)
treecf5d014793d54bd26735cb776b729814b7cb5a78 /src/raylib.h
parent129c890a28b50c2ce3820e3745f8c89c8833f02c (diff)
downloadraylib-2536bea379387e525e3107ee07355292ee87a566.tar.gz
raylib-2536bea379387e525e3107ee07355292ee87a566.zip
Added: ImageResizeCanvas() -WIP-
Added note idea on ImageFormat() for future redesign (to support 16bit-32bit pixel-formats)
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/raylib.h b/src/raylib.h
index e83650e6..2659d70d 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -912,8 +912,9 @@ RLAPI void ImageAlphaClear(Image *image, Color color, float threshold);
RLAPI void ImageAlphaCrop(Image *image, float threshold); // Crop image depending on alpha value
RLAPI void ImageAlphaPremultiply(Image *image); // Premultiply alpha channel
RLAPI void ImageCrop(Image *image, Rectangle crop); // Crop an image to a defined rectangle
-RLAPI void ImageResize(Image *image, int newWidth, int newHeight); // Resize and image (bilinear filtering)
-RLAPI void ImageResizeNN(Image *image,int newWidth,int newHeight); // Resize and image (Nearest-Neighbor scaling algorithm)
+RLAPI void ImageResize(Image *image, int newWidth, int newHeight); // Resize image (bilinear filtering)
+RLAPI void ImageResizeNN(Image *image, int newWidth,int newHeight); // Resize image (Nearest-Neighbor scaling algorithm)
+RLAPI void ImageResizeCanvas(Image *image, int newWidth,int newHeight, int anchor, Color color); // Resize canvas, using anchor point and color filling
RLAPI void ImageMipmaps(Image *image); // Generate all mipmap levels for a provided image
RLAPI void ImageDither(Image *image, int rBpp, int gBpp, int bBpp, int aBpp); // Dither image data to 16bpp or lower (Floyd-Steinberg dithering)
RLAPI Image ImageText(const char *text, int fontSize, Color color); // Create an image from text (default font)